/**
 * Arduino Sketch für SmartHome yourself - Arduino Lehrgang
 * 
 * Tag 9: Arrays
 * In diesem Sketch bauen wir eine Pegel-Anzeige die den Wert der Poti-Einstellung anzeigt. 
 * Im Unterschied zur Pegel-Anzeige aus  Tag 8 gibt es nun nicht nur 4 Pegel-Stufen. 
 * Zwischenschritte zwischen den einzelnen LEDs werden hier durch dimmen der LED angezeigt.
 * 
 * https://www.arduino.cc/reference/de/language/variables/data-types/array/
 * 
 * By Daniel Scheidler - Dezember 2019
 */

const unsigned int POTI_PIN = A0;                                  // globale Konstante für Pin mit Poti

const unsigned int LED_PINS[4] = {3, 5, 6, 9};                     // Array zum definieren der PINs für LEDs
                                                                   // So kann man die Pins in einer For-Schleife der Reihe nach abarbeiten,
                                                                   // ohne dass es sich um aufeinander folgende PINs handelt.
                                                                   // Das ist in diesem Fall notwendig, da alle LEDs an einem PWM-fähigen GPIO 
                                                                   // angeschlossen sein müssen, diese aber nicht aufeinanderfolgend sind.
void setup() {
  Serial.begin(38400);

  for(int pin = 0; pin < 4; pin++){
    pinMode(LED_PINS[pin], OUTPUT);                                // PINs von MIN_LED_PIN bis MAX_LED_PIN als OUTPUT festlegen.
  }
  pinMode(POTI_PIN, INPUT);
}


void loop() {
  int potiValue = analogRead(POTI_PIN);                            // Variable für Poti-Wert 
  
  Serial.print("gemessener Poti-Wert: ");
  Serial.println(potiValue);

  int pegel = potiValue * 4;                                       // Pegel mit 4 Multiplizieren um den Wert auf 4 Bereiche aufzuteilen 
  Serial.print("Ermittelter Pegel-Wert: ");
  Serial.println(pegel);

  for(int ledIndex = 0; ledIndex < 4; ledIndex++){                 // For-Schleife um Helligkeit der 4 LEDs zu ermitteln und zu setzen.
    int brightness = (pegel - ((ledIndex) * 1023))/4;              // Helligkeitswert für aktuelle LED ermitteln. 
                                                                   // Durch abziehen von (LED-Index*1023) vom Pegel sind LEDs unterhalb des Pegels
                                                                   // größer als 1023, die LEDs oberhalb des Pegels kleiner als Null und die LED des Pegels
                                                                   // zwischen 0 und 1023. 
                                                                   // Durch das dividieren mit 4 wird ein für analogWrite gültiger Wert (0-255) erzeugt. 
    if(brightness > 255){
      brightness = 255;                                            // Alle LEDs mit Helligkeitswert > 255 volle Helligkeit einstellen
    } else if(brightness < 0){
      brightness = 0;                                              // Alle LEDs mit Helligkeitswert < 0 minimale Helligkeit einstellen
    }

    Serial.print("Pin: ");
    Serial.print(LED_PINS[ledIndex]);
    Serial.print(" / ");
    Serial.println(brightness);

    analogWrite(LED_PINS[ledIndex], brightness);                   // Helligkeitswert für LED setzen.
  }
 
  delay(50);
}
